;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
function patch_load_psfs, state, dummy
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

nb_of_psfs = state.par.cols*state.par.rows
  ;PSF TYPE = 0 --> single file (cube)
  if state.par.psf_type EQ 0 then begin
     psf = readfits((*state.par.psf_filename)[0], /SILENT)
     NP=(size(psf))[1]
     MP=(size(psf))[2]
     if (size(psf))[0] EQ 2 then PP=1 else PP=(size(psf))[3]
     if (PP NE nb_of_psfs) then begin
        a=dialog_message(["You must load a cube FITS file. The  ", $ 
                          "dimensions should be NxMxP, where P  ",$
                          "is the number of sub-domains."], $
                          dialog_parent=dummy, /ERROR)
        return, 0
     endif
     if (PP EQ 1) then begin
        info=["filename: "+(*state.par.psf_filename)[0], $
              "size: "+strtrim(NP,1)+' x '+strtrim(MP,1), $
              " ", $
              " "] 
     endif else begin
        info=["filename: "+(*state.par.psf_filename)[0], $
              "size: "+strtrim(NP,1)+' x '+strtrim(MP,1)+' x '+strtrim(PP,1), $
              " ", $
              " "]
     endelse
     ;show info
     WIDGET_CONTROL, state.id.psf_info, SET_VALUE=info
     if (NP LT state.par.domx+2*state.par.overlap) OR $
        (MP LT state.par.domy+2*state.par.overlap) then begin
        a=dialog_message(["The dimensions of the PSFs will be zero-padded", $
                          "in order to fit the size of the sub-domains.  ",$
                          "(plus the 2*overlap value)."], $
                          dialog_parent=dummy)
     endif
  endif
  ; PSF TYPE = 1 --> multiple files
  if state.par.psf_type EQ 1 then begin
     psf0=readfits((*state.par.psf_filename)[0], /SILENT)
     NP=(size(psf0))[1]
     MP=(size(psf0))[2]
     if (size(psf0))[0] EQ 2 then PP=1 else begin 
        a=dialog_message("Please, check the dimensions of the first PSF. ", $ 
                        dialog_parent=dummy, /ERROR)
        return, 0
     endelse
     info=["filename: "+(*state.par.psf_filename)[0], $
           "size: "+strtrim(NP,1)+' x '+strtrim(MP,1), $
           "First PSF loaded... ", $
           "... checking for other files"]
     ;show info (first PSF)
     WIDGET_CONTROL, state.id.psf_info, SET_VALUE=info
     ok_go_on=1
     for k=1,nb_of_psfs-1 do begin
         psf=readfits((*state.par.psf_filename)[k],/SILENT)
         if (size(psf0, /N_ELE) NE size(psf, /N_ELE)) then begin
            a=dialog_message("Please, check the dimensions of PSF nb "+strtrim(k,1), $
                             dialog_parent=dummy, /ERROR)
            ok_go_on=0
         endif
     endfor
     if (NP LT state.par.domx+2*state.par.overlap) OR $
        (MP LT state.par.domy+2*state.par.overlap) then begin
        a=dialog_message(["The dimensions of the PSFs will be zero-padded", $
                          "in order to fit the size of the sub-domains.  ",$
                          "(plus the 2*overlap value)."], $
                          dialog_parent=dummy)
     endif
     if (ok_go_on) then begin 
        info=["filename: "+(*state.par.psf_filename)[0], $
              "size: "+strtrim(NP,1)+' x '+$
                           strtrim(MP,1)+' x '+$
                           strtrim(nb_of_psfs,1), $
              "  ", $
              "All files are OK."]
     endif else begin
        info=["filename: "+(*state.par.psf_filename)[0], $
              "size: "+strtrim(NP,1)+' x '+$
                           strtrim(MP,1), $
              "    ERROR!    ", $             
              "Check your files and re-load PSFs "]
     endelse
     ;show info (OK or ERROR)
     WIDGET_CONTROL, state.id.psf_info, SET_VALUE=info
     return, 1 
  endif
end
